# kafka-connect-cli
A simple CLI for Kafka connect [REST API](https://docs.confluent.io/platform/7.0.1/connect/references/restapi.html)

Install from PyPi
```commandline
pip install kafka-connect-cli
```